@@ -5,7 +5,7 @@ sets of 2D points.
 
 :Authors: Mihai Cara, Warren Hack
 
-:License: :doc:`../LICENSE`
+:License: :doc:`LICENSE`
 
 """
 import logging
@@ -18,9 +18,10 @@ from astropy.modeling.fitting import LevMarLSQFitter
 if Version(astropy.__version__) >= Version('5.1'):
     from astropy.modeling.fitting import fitter_to_model_params
 else:
-    from astropy.modeling.fitting import _fitter_to_model_params as fitter_to_model_params
+    from astropy.modeling.fitting import (_fitter_to_model_params as
+                                          fitter_to_model_params)
 
-from .linalg import inv
+from . linalg import inv
 from . import __version__  # noqa: F401
 
 __author__ = 'Mihai Cara, Warren Hack'
@@ -149,9 +150,10 @@ def iter_linear_fit(xy, uv, wxy=None, wuv=None,
     clip_accum: bool, optional
         Indicates whether or not to reset the list of "bad" (clipped out)
         sources after each clipping iteration. When set to `True` the list
-        only grows with each iteration as "bad" positions never re-enter the
-        pool of available position for the fit. By default the list of
-        "bad" source positions is purged at each iteration.
+        only grows with each iteration as "bad" positions never re-enter
+        the pool of available position for the fit. By default the list of
+        "bad" source positions is purged at each iteration. This parameter
+        is ignored when ``nclip`` is either `None` or 0.
 
     Returns
     -------
